abbrev 0 0
abbrev 10q {thank you}
abbrev 2b {to be}
abbrev 2ni tonight
abbrev DNl4 {The Netherlands}
abbrev Dnl4 {The Netherlands}
abbrev SFr {San Francisco}
abbrev ZA4 {South Africa}
abbrev a1 anyone
abbrev ab about
abbrev ab2 {about to}
abbrev acc according
abbrev acc2 {according to}
abbrev accly accordingly
abbrev acct account
abbrev acctg accounting
abbrev accts accounts
abbrev acr across
abbrev addl additional
abbrev addn addition
abbrev addn2 {addition to}
abbrev addns additions
abbrev addr address
abbrev addrs addresses
abbrev addy additionally
abbrev adv advance
abbrev advs advances
abbrev af after
abbrev afaik {as far as I know}
abbrev afn afternoon
abbrev afr afraid
abbrev afw afterwards
abbrev ag again
abbrev agst against
abbrev ahd ahead
abbrev ak4 alaska
abbrev aka a/k/a
abbrev al along
abbrev alm almost
abbrev alr already
abbrev alri {all right}
abbrev altho although
abbrev altog altogether
abbrev alw always
abbrev amg among
abbrev amt amount
abbrev amts amounts
abbrev and'n question
abbrev and'ns questions
abbrev ann't announcement
abbrev ann'ts announcements
abbrev anod another
abbrev any1 anyone
abbrev anyb anybody
abbrev anyth anything
abbrev anyti anytime
abbrev anywh anywhere
abbrev anywhe anywhere
abbrev appl application
abbrev appls applications
abbrev appt appointment
abbrev appts appointments
abbrev apr4 april
abbrev apt apartment
abbrev apts apartments
abbrev aqi {ameet and ilene}
abbrev ar around
abbrev arl article
abbrev arls articles
abbrev asst assistant
abbrev assts assistants
abbrev atl article
abbrev atls articles
abbrev attn attention
abbrev attn2 {attention to}
abbrev attns attentions
abbrev atty attorney
abbrev attys attorneys
abbrev aug4 august
abbrev av available
abbrev av2 {available to}
abbrev avg average
abbrev avgs averages
abbrev avl available
abbrev avlty availability
abbrev avty availability
abbrev az4 arizona
abbrev b but
abbrev ba {be able to}
abbrev ba2 {be able to}
abbrev bc because
abbrev bco {because of}
abbrev bcod {because of the}
abbrev bday birthday
abbrev bdays birthdays
abbrev bdy birthday
abbrev bdys birthdays
abbrev bedr bedroom
abbrev bedrs bedrooms
abbrev bef before
abbrev beh behind
abbrev betw between
abbrev bf before
abbrev bfast breakfast
abbrev bfasts breakfasts
abbrev bfh beforehand
abbrev bfr boyfriend
abbrev bfrs boyfriends
abbrev bg being
abbrev bgg beginning
abbrev bggs beginnings
abbrev bgs beings
abbrev bk break
abbrev bkgd background
abbrev bkgds backgrounds
abbrev bks breaks
abbrev bl blind
abbrev bldg building
abbrev bldgs buildings
abbrev blg blinding
abbrev bls blinds
abbrev bn been
abbrev bo both
abbrev bos boston
abbrev bot bought
abbrev br better
abbrev bri bright
abbrev brot brought
abbrev bs backspace
abbrev bss backspaces
abbrev bw backward
abbrev bws backwards
abbrev c can
abbrev ca4 california
abbrev cbr cambridge
abbrev ccd concord
abbrev cd could
abbrev cdb {could be}
abbrev cdh {could have}
abbrev cdhb {could have been}
abbrev cdhbn {could have been}
abbrev cdn couldn't
abbrev cdnb {couldn't be}
abbrev cdnh {couldn't have}
abbrev cdnhb {couldn't have been}
abbrev cdnhbn {couldn't have been}
abbrev cdy {could you}
abbrev cert certainly
abbrev cfgr configure
abbrev cfgrg configuring
abbrev cfgrn configuration
abbrev cfgrs configures
abbrev cg change
abbrev cgs changes
abbrev chn chinese
abbrev cied copied
abbrev cl class
abbrev cls classes
abbrev cmnd command
abbrev cmnds commands
abbrev cn can't
abbrev co4 colorado
abbrev comf comfortable
abbrev comfly comfortably
abbrev comg coming
abbrev comm communication
abbrev comms communications
abbrev confedn federation
abbrev confedns federations
abbrev confn configuration
abbrev confns configurations
abbrev conv't convenient
abbrev conv'tly conveniently
abbrev convt convert
abbrev convt2 {convert to}
abbrev convted converted
abbrev convted2 {converted to}
abbrev convtg converting
abbrev convtg2 {converting to}
abbrev convts {converts to}
abbrev convts2 converts
abbrev cou couple
abbrev cous couples
abbrev cpt computer
abbrev cptg computing
abbrev cpts computers
abbrev ct4 connecticut
abbrev cties communities
abbrev ctr center
abbrev ctre centre
abbrev ctres centres
abbrev ctrs centers
abbrev cttee committee
abbrev cttees committees
abbrev ctties communities
abbrev ctty community
abbrev cttys communities
abbrev cty community
abbrev ctys communities
abbrev curr current
abbrev currs currents
abbrev cy copy
abbrev cyd copied
abbrev cyg copying
abbrev cying copying
abbrev cys copies
abbrev d the
abbrev dNl4 {the Netherlands}
abbrev dau daughter
abbrev daus daughters
abbrev ddn didn't
abbrev de there
abbrev de4 delaware
abbrev dec4 december
abbrev defn definition
abbrev defns definitions
abbrev deir their
abbrev deirf theirselves
abbrev deirs theirs
abbrev del delete
abbrev dels deletes
abbrev dem them
abbrev demf themselves
abbrev den then
abbrev depm department
abbrev depms departments
abbrev dept department
abbrev deptl departmental
abbrev depts departments
abbrev des these
abbrev dese these
abbrev devt development
abbrev devts developments
abbrev dey they
abbrev deyr they're
abbrev deyv they've
abbrev dez these
abbrev dg doing
abbrev dif different
abbrev difce difference
abbrev difces differences
abbrev dir directory
abbrev dirn direction
abbrev dirns directions
abbrev dirs directories
abbrev dis this
abbrev distn distribution
abbrev distns distributions
abbrev dm them
abbrev dmf themselves
abbrev dn doesn't
abbrev dne {david and ellen}
abbrev dnl4 {the netherlands}
abbrev dnti downtime
abbrev doc document
abbrev docn documentation
abbrev docns documentations
abbrev docs documents
abbrev doro thorough
abbrev doroly thoroughly
abbrev downti downtime
abbrev doz those
abbrev dqe {david and ellen}
abbrev durg during
abbrev dv david
abbrev dy {do you}
abbrev dyh {do you have}
abbrev dyk {do you know}
abbrev e even
abbrev ea each
abbrev eg e.g.
abbrev ei either
abbrev elt element
abbrev elts elements
abbrev em email
abbrev ems emails
abbrev en enough
abbrev engl english
abbrev engrg engineering
abbrev enuf enough
abbrev envt environment
abbrev envts environments
abbrev eo {each other}
abbrev eod {each other}
abbrev esp especially
abbrev ev ever
abbrev ev1 everyone
abbrev evb everybody
abbrev evg evening
abbrev evgs evenings
abbrev evt event
abbrev evth everything
abbrev evts events
abbrev evwh everywhere
abbrev evy every
abbrev ewh everywhere
abbrev ewr newark
abbrev ex example
abbrev exc except
abbrev excf {except for}
abbrev excn exception
abbrev excnl exceptional
abbrev excnly exceptionally
abbrev excns exceptions
abbrev exct {except that}
abbrev exs examples
abbrev extl external
abbrev extls externals
abbrev ey every
abbrev f for
abbrev fdo {found out}
abbrev fe {for example}
abbrev feb4 february
abbrev fedl federal
abbrev fedn federation
abbrev fedns federations
abbrev fi {for instance}
abbrev fl floor
abbrev fl4 florida
abbrev flg following
abbrev fls floors
abbrev fmt format
abbrev fmts formats
abbrev fo {find out}
abbrev folg following
abbrev follg following
abbrev fon phone
abbrev fons phones
abbrev fr from
abbrev fr4 friday
abbrev fri4 friday
abbrev ftm {for that matter}
abbrev fw forward
abbrev fwd forward
abbrev fwed forwarded
abbrev fwg forwarding
abbrev fws forwards
abbrev fy {fiscal year}
abbrev fys {fiscal years}
abbrev g good
abbrev gd good
abbrev genl general
abbrev genlly generally
abbrev gf girlfriend
abbrev gfd greenfield
abbrev gfld greenfield
abbrev gfr girlfriend
abbrev gfrs girlfriends
abbrev gfs girlfriends
abbrev gg going
abbrev gg2 {going to}
abbrev gg2b {going to be}
abbrev gg2ba {going to be able to}
abbrev gg2ba2 {going to be able to}
abbrev gg2h {going to have}
abbrev gg2h2 {going to have to}
abbrev gi give
abbrev gis gives
abbrev givg giving
abbrev gmc germanic
abbrev gmn german
abbrev gmns germans
abbrev gmny germany
abbrev gn given
abbrev govt government
abbrev govts governments
abbrev gp group
abbrev gps groups
abbrev gr great
abbrev grly greatly
abbrev grr greater
abbrev gt great
abbrev gter greater
abbrev gtr greater
abbrev h have
abbrev h2 {have to}
abbrev h2b {have to be}
abbrev havg having
abbrev hd heidi
abbrev herf herself
abbrev hev however
abbrev hf himself
abbrev hg having
abbrev hi4 hawaii
abbrev himf himself
abbrev hm him
abbrev hmf himself
abbrev hn haven't
abbrev ho home
abbrev hos homes
abbrev howev however
abbrev hr hour
abbrev hrs hours
abbrev hvn {new haven}
abbrev hw hardware
abbrev hy {have you}
abbrev i'f interface
abbrev i'fs interfaces
abbrev ie i.e.
abbrev il4 illinois
abbrev im i'm
abbrev impt important
abbrev imptly importantly
abbrev incl including
abbrev inclg including
abbrev incls includes
abbrev indiv individual
abbrev indivs individuals
abbrev inf information
abbrev insi inside
abbrev inst instead
abbrev instn installation
abbrev instns installations
abbrev insto {instead of}
abbrev internatl international
abbrev intl international
abbrev iqa {ilene and ameet}
abbrev ist instead
abbrev istn installation
abbrev istns installations
abbrev isto {instead of}
abbrev itf itself
abbrev jan4 january
abbrev jpn japanese
abbrev jqa {judy and amanda}
abbrev jt just
abbrev jul4 july
abbrev jun4 june
abbrev k kind
abbrev ka kinda
abbrev kbd keyboard
abbrev kbds keyboards
abbrev kn know
abbrev kng knowing
abbrev knk {kate and kanthan}
abbrev knn known
abbrev kns knows
abbrev ko {kind of}
abbrev kqk {kate and kanthan}
abbrev ks kinds
abbrev kso {kinds of}
abbrev kt kate
abbrev ky4 kentucky
abbrev l will
abbrev lang language
abbrev langs languages
abbrev lf left
abbrev lg language
abbrev lgs languages
abbrev li like
abbrev ling linguistic
abbrev lings linguistics
abbrev lk look
abbrev lkg looking
abbrev lks looks
abbrev ll little
abbrev lookg looking
abbrev lr later
abbrev ltr letter
abbrev ltrs letters
abbrev lx linguistics
abbrev ly {will you}
abbrev m more
abbrev ma4 massachusetts
abbrev makg making
abbrev makgs makings
abbrev manl manual
abbrev manls manuals
abbrev mar4 march
abbrev may4 may
abbrev mb maybe
abbrev md4 maryland
abbrev me4 maine
abbrev mgmt management
abbrev mgmts managements
abbrev mgr manager
abbrev mgrs managers
abbrev mi might
abbrev mi4 michigan
abbrev midni midnight
abbrev midnis midnights
abbrev min minute
abbrev mins minutes
abbrev ml margoleath
abbrev mo4 monday
abbrev mol {more or less}
abbrev mon4 monday
abbrev monog monogamous
abbrev monogly monogamously
abbrev monogy monogamy
abbrev mrg morning
abbrev mssg message
abbrev mssgs messages
abbrev mst mostly
abbrev mtg meeting
abbrev mtgs meetings
abbrev mvt movement
abbrev mvts movements
abbrev mx4 mexico
abbrev myf myself
abbrev n not
abbrev n9 {nonoxynol 9}
abbrev natl national
abbrev natlities nationalities
abbrev natlity nationality
abbrev natlly nationally
abbrev natly nationaly
abbrev nb {new brunswick}
abbrev nbr {new brunswick}
abbrev nc {north carolina}
abbrev neccies necessaries
abbrev neccily necessarily
abbrev neccy necessary
abbrev necies necessaries
abbrev necily necessarily
abbrev necy necessary
abbrev nei neither
abbrev nev never
abbrev newh anywhere
abbrev ng newsgroup
abbrev ngs newsgroups
abbrev ni night
abbrev nis night
abbrev nite night
abbrev nites night
abbrev nj4 {new jersey}
abbrev nl4 netherlands
abbrev nm4 {new mexico}
abbrev nnj {neils and julianne}
abbrev noho northampton
abbrev nonmon nonmonogamous
abbrev nonmonly nonmonogamously
abbrev nonmonog nonmonogamous
abbrev nonmonogly nonmonogamously
abbrev nonmonogy nonmonogamy
abbrev nonmony nonmonogamy
abbrev noth nothing
abbrev nov4 november
abbrev nrg energy
abbrev nrgs energies
abbrev num number
abbrev nums numbers
abbrev nw network
abbrev nwg networking
abbrev nwk network
abbrev nwks networks
abbrev nws networks
abbrev nx next
abbrev nxs NeXTstation
abbrev nxss NeXTstations
abbrev ny4 {new york}
abbrev nyc {new york city}
abbrev o of
abbrev oc {of course}
abbrev oct4 october
abbrev od other
abbrev odr other
abbrev ods others
abbrev odw otherwise
abbrev odwi otherwise
abbrev odwise otherwise
abbrev ofc office
abbrev ofcs offices
abbrev onef oneself
abbrev ongg ongoing
abbrev oppies opportunities
abbrev oppy opportunity
abbrev oppys opportunities
abbrev ops operations
abbrev org organization
abbrev orgs organizations
abbrev ot ought
abbrev otoh {on the other hand}
abbrev ou out
abbrev ouf ourselves
abbrev ourf ourselves
abbrev ous outside
abbrev ousi outside
abbrev outs outside
abbrev ov over
abbrev overni overnight
abbrev ovni overnight
abbrev p people
abbrev pa4 pennsylvania
abbrev perh perhaps
abbrev permn permission
abbrev permns permissions
abbrev pgh pittsburgh
abbrev pgh4 pittsburgh
abbrev pkg package
abbrev pkgs packages
abbrev pl please
abbrev pls pleases
abbrev pn person
abbrev pns persons
abbrev poss possible
abbrev possies possibilities
abbrev possity possibility
abbrev possitys possibilities
abbrev possly possibly
abbrev possties possibilities
abbrev possty possibility
abbrev posstys possibilities
abbrev possy possibility
abbrev possys possibilities
abbrev pri princeton
abbrev prly probably
abbrev prob problem
abbrev probs problems
abbrev professor'l professional
abbrev professor'ls professionals
abbrev professor'n profession
abbrev professor'ns professions
abbrev prog program
abbrev progg programming
abbrev progs programs
abbrev prolly probably
abbrev prov providence
abbrev pt point
abbrev pted pointed
abbrev ptr pointer
abbrev ptrs pointers
abbrev pts points
abbrev pw password
abbrev pwr power
abbrev pwrs powers
abbrev pws passwords
abbrev px phoenix
abbrev q and
abbrev qa a
abbrev qah ahead
abbrev qb b
abbrev qbs bs
abbrev qc c
abbrev qcd cd
abbrev qd d
abbrev qdel del
abbrev qdoc doc
abbrev qe e
abbrev qex ex
abbrev qf f
abbrev qg g
abbrev qh h
abbrev qi i
abbrev qic ic
abbrev qj j
abbrev qk k
abbrev ql l
abbrev qm m
abbrev qmsgs msgs
abbrev qn n
abbrev qng ng
abbrev qnj nj
abbrev qo o
abbrev qp p
abbrev qpp pp
abbrev qq q
abbrev qr r
abbrev qrn rn
abbrev qs s
abbrev qt t
abbrev qu u
abbrev qun question
abbrev quns questions
abbrev qv v
abbrev qw w
abbrev qx x
abbrev qy y
abbrev qz z
abbrev r are
abbrev ra rhonda
abbrev rad rather
abbrev reln relation
abbrev relns relations
abbrev relp relationship
abbrev relps relationships
abbrev repl replace
abbrev repl't replacement
abbrev repl'ts replacements
abbrev repls replaces
abbrev replt replacement
abbrev replts replacements
abbrev rept report
abbrev reptg reporting
abbrev repts reports
abbrev resp responsible
abbrev resp2 {responsible to}
abbrev resp2d {responsible to the}
abbrev resp4 {responsible for}
abbrev resp4d {responsible for the}
abbrev respf {responsible for}
abbrev respfd {responsible for the}
abbrev resply responsibly
abbrev respties responsibilities
abbrev respty responsibility
abbrev resptys responsibilities
abbrev ri right
abbrev ris rights
abbrev rl rachel
abbrev rn aren't
abbrev rsrc resource
abbrev rsrcs resources
abbrev rus russian
abbrev rxn relation
abbrev rxnp relationship
abbrev rxnps relationships
abbrev rxns relations
abbrev rxv receive
abbrev rxvs receives
abbrev ry {are you}
abbrev s some
abbrev s1 someone
abbrev sa sorta
abbrev sa4 saturday
abbrev sat4 saturday
abbrev sb somebody
abbrev sch schedule
abbrev sched schedule
abbrev scheds schedules
abbrev sd should
abbrev sdb {should be}
abbrev sdh {should have}
abbrev sdh2b {should have to be}
abbrev sdhbn {should have been}
abbrev sdn shouldn't
abbrev sdnb {shouldn't be}
abbrev sdnh {shouldn't have}
abbrev sec second
abbrev secs seconds
abbrev sect section
abbrev sects sections
abbrev sel select
abbrev selg selecting
abbrev seln selection
abbrev selns selections
abbrev sels selects
abbrev sep separate
abbrev sep4 september
abbrev sepg separating
abbrev seply separately
abbrev seps separates
abbrev sev several
abbrev sevl several
abbrev sevlly severally
abbrev sevly severally
abbrev sfr {san francisco}
abbrev sh somehow
abbrev shd should
abbrev sim similar
abbrev sim2 {similar to}
abbrev simly similarly
abbrev simly2 {similarly to}
abbrev sj subject
abbrev sjs subjects
abbrev sld should
abbrev soln solution
abbrev solns solutions
abbrev spl someplace
abbrev sq square
abbrev sqs squares
abbrev sr storyreading
abbrev ss SPARCstation
abbrev sss SPARCstations
abbrev ssv SPARCserver
abbrev ssvs SPARCservers
abbrev std {so that the}
abbrev sth something
abbrev sti sometime
abbrev stis sometimes
abbrev stl {st. louis}
abbrev str straight
abbrev str8fw straightforward
abbrev str8fwly straightforwardly
abbrev str8s straight
abbrev strfw straightforward
abbrev strfwly straightforwardly
abbrev strs straights
abbrev su4 sunday
abbrev subdir subdirectory
abbrev subdirs subdirectories
abbrev subj subject
abbrev subjs subjects
abbrev sun4 sunday
abbrev sv SunView
abbrev svc service
abbrev svcs services
abbrev svil somerville
abbrev sville somerville
abbrev sw software
abbrev swh somewhat
abbrev swhe somewhere
abbrev sys system
abbrev syss systems
abbrev t that
abbrev talkg talking
abbrev tdy today
abbrev tg together
abbrev tgvg thanksgiving
abbrev tgvgs thanksgivings
abbrev th thing
abbrev th4 thursday
abbrev they'v they've
abbrev tho though
abbrev thoro thorough
abbrev thoroly thoroughly
abbrev thot thought
abbrev thots thoughts
abbrev thru through
abbrev ths things
abbrev thu4 thursday
abbrev ti time
abbrev tis times
abbrev tmw tomorrow
abbrev tn than
abbrev tod today
abbrev tog together
abbrev toni tonight
abbrev tou touch
abbrev trad tradition
abbrev tradl traditional
abbrev tradlly traditionally
abbrev tu4 tuesday
abbrev tue4 tuesday
abbrev tx thanks
abbrev tx4 texas
abbrev txj {thanks, ---j.}
abbrev ty type
abbrev tys types
abbrev u you
abbrev ud you'd
abbrev ug undergrad
abbrev ugs undergrads
abbrev ul you'll
abbrev unav unavailable
abbrev unav2 {unavailable to}
abbrev uncomf uncomfortable
abbrev uncomfly uncomfortably
abbrev unf unfortunately
abbrev unfe unfortunate
abbrev uni university
abbrev unis universities
abbrev unl unless
abbrev unusu unusually
abbrev ur your
abbrev usg using
abbrev ust understand
abbrev ustd understood
abbrev ustg understanding
abbrev usts understands
abbrev usu usually
abbrev uv you've
abbrev ux unix
abbrev v very
abbrev va4 virginia
abbrev vac vacation
abbrev vacn vacation
abbrev vacns vacations
abbrev vacs vacations
abbrev vk vicki
abbrev vn version
abbrev vns versions
abbrev vol volume
abbrev vols volumes
abbrev vt4 vermont
abbrev w with
abbrev wa4 washington
abbrev wd would
abbrev wdb {would be}
abbrev wdh {would have}
abbrev wdn wouldn't
abbrev wdnb {wouldn't be}
abbrev wdnh {wouldn't have}
abbrev wdy {would you}
abbrev we4 wednesday
abbrev wea weather
abbrev weas weathers
abbrev wed4 wednesday
abbrev wh which
abbrev whatev whatever
abbrev whe where
abbrev whed whether
abbrev wheev wherever
abbrev whenev whenever
abbrev whereev wherever
abbrev whev whatever
abbrev whoev whoever
abbrev whv whatever
abbrev wi4 wisconsin
abbrev wim women
abbrev wims women's
abbrev winsys {windowing system}
abbrev winsyss {windowing systems}
abbrev wk week
abbrev wkend weekend
abbrev wkends weekends
abbrev wknd weekend
abbrev wkni weeknight
abbrev wks weeks
abbrev wm woman
abbrev wmm women
abbrev wmms women's
abbrev wms women
abbrev wn wasn't
abbrev wo without
abbrev wom woman
abbrev woms woman's
abbrev workg working
abbrev wr wrong
abbrev wri write
abbrev wris writes
abbrev ws workstation
abbrev wsp workspace
abbrev wsps workspaces
abbrev wss workstations
abbrev ww window
abbrev wwin within
abbrev wws windows
abbrev xc except
abbrev xdoc document
abbrev xlnc excellency
abbrev xlnt excellent
abbrev xmas christmas
abbrev xmass christmasses
abbrev xmt transmit
abbrev xmts transmits
abbrev xsect intersect
abbrev xsectn intersection
abbrev xsectns intersections
abbrev xsects intersects
abbrev xw {X Windows}
abbrev xy christy
abbrev y you
abbrev yd you'd
abbrev ydy yesterday
abbrev yf yourself
abbrev yk {you know}
abbrev yl you'll
abbrev you'l you'll
abbrev you'r you're
abbrev yr your
abbrev yrs yours
abbrev yves yourselves
abbrev yvs yourselves
abbrev yy y'all
abbrev za4 {south africa}
abbrev za4's {south africa's}
